imitation package
=================

Subpackages
-----------

.. toctree::

   imitation.algorithms
   imitation.data
   imitation.envs
   imitation.policies
   imitation.rewards
   imitation.scripts
   imitation.util


Module contents
---------------

.. automodule:: imitation
